@@ -9,7 +9,7 @@ use NEXT;
 
 use HTML::QuickTable;
 
-our $VERSION = 0.42;
+our $VERSION = 0.421;
 
 =head1 NAME
 
@@ -291,7 +291,9 @@ sub _tabulate_object
     {
         return '' unless @_;
         return @_ if @_ == 1;
-        return join( "\n", '<ol>', ( map { "<li>$_</li>" } @_ ), '</ol>' );
+        #return join( "\n", '<ol>', ( map { "<li>$_</li>" } @_ ), '</ol>' );
+        return join ' | ', @_ if @_ < 3 or $self->action =~ /view/;
+        return join ' | ', $_[0], $_[1], @_ - 2 . ' more...';
     };
     
     # XXX: getting a 'Use of uninitialized value in string eq warning' - looks like 
